<?php
/**
 * SEO Digital Marketing: Customizer
 *
 * @subpackage SEO Digital Marketing
 * @since 1.0
 */

function seo_digital_marketing_customize_register( $wp_customize ) {

	wp_enqueue_style('customizercustom_css', esc_url( get_template_directory_uri() ). '/assets/css/customizer.css');

	// Add custom control.
  	require get_parent_theme_file_path( 'inc/customize/customize_toggle.php' );

	// Register the custom control type.
	$wp_customize->register_control_type( 'SEO_Digital_Marketing_Toggle_Control' );

	$wp_customize->add_section( 'seo_digital_marketing_typography_settings', array(
		'title'       => __( 'Typography', 'seo-digital-marketing' ),
		'priority'       => 24,
	) );

	$font_choices = array(
		'' => 'Select',
		'Source Sans Pro:400,700,400italic,700italic' => 'Source Sans Pro',
		'Open Sans:400italic,700italic,400,700' => 'Open Sans',
		'Oswald:400,700' => 'Oswald',
		'Playfair Display:400,700,400italic' => 'Playfair Display',
		'Montserrat:400,700' => 'Montserrat',
		'Raleway:400,700' => 'Raleway',
		'Droid Sans:400,700' => 'Droid Sans',
		'Lato:400,700,400italic,700italic' => 'Lato',
		'Arvo:400,700,400italic,700italic' => 'Arvo',
		'Lora:400,700,400italic,700italic' => 'Lora',
		'Merriweather:400,300italic,300,400italic,700,700italic' => 'Merriweather',
		'Oxygen:400,300,700' => 'Oxygen',
		'PT Serif:400,700' => 'PT Serif',
		'PT Sans:400,700,400italic,700italic' => 'PT Sans',
		'PT Sans Narrow:400,700' => 'PT Sans Narrow',
		'Cabin:400,700,400italic' => 'Cabin',
		'Fjalla One:400' => 'Fjalla One',
		'Francois One:400' => 'Francois One',
		'Josefin Sans:400,300,600,700' => 'Josefin Sans',
		'Libre Baskerville:400,400italic,700' => 'Libre Baskerville',
		'Arimo:400,700,400italic,700italic' => 'Arimo',
		'Ubuntu:400,700,400italic,700italic' => 'Ubuntu',
		'Bitter:400,700,400italic' => 'Bitter',
		'Droid Serif:400,700,400italic,700italic' => 'Droid Serif',
		'Roboto:400,400italic,700,700italic' => 'Roboto',
		'Open Sans Condensed:700,300italic,300' => 'Open Sans Condensed',
		'Roboto Condensed:400italic,700italic,400,700' => 'Roboto Condensed',
		'Roboto Slab:400,700' => 'Roboto Slab',
		'Yanone Kaffeesatz:400,700' => 'Yanone Kaffeesatz',
		'Rokkitt:400' => 'Rokkitt',
	);

	$wp_customize->add_setting( 'seo_digital_marketing_headings_text', array(
		'sanitize_callback' => 'seo_digital_marketing_sanitize_fonts',
	));

	$wp_customize->add_control( 'seo_digital_marketing_headings_text', array(
		'type' => 'select',
		'description' => __('Select your suitable font for the headings.', 'seo-digital-marketing'),
		'section' => 'seo_digital_marketing_typography_settings',
		'choices' => $font_choices
	));

	$wp_customize->add_setting( 'seo_digital_marketing_body_text', array(
		'sanitize_callback' => 'seo_digital_marketing_sanitize_fonts'
	));

	$wp_customize->add_control( 'seo_digital_marketing_body_text', array(
		'type' => 'select',
		'description' => __( 'Select your suitable font for the body.', 'seo-digital-marketing' ),
		'section' => 'seo_digital_marketing_typography_settings',
		'choices' => $font_choices
	) );

 	$wp_customize->add_section('seo_digital_marketing_pro', array(
        'title'    => __('UPGRADE SEO MARKETING PREMIUM', 'seo-digital-marketing'),
        'priority' => 1,
    ));

    $wp_customize->add_setting('seo_digital_marketing_pro', array(
        'default'           => null,
        'sanitize_callback' => 'sanitize_text_field',
    ));
    $wp_customize->add_control(new SEO_Digital_Marketing_Pro_Control($wp_customize, 'seo_digital_marketing_pro', array(
        'label'    => __('BUSINESS SEO MARKETING PREMIUM', 'seo-digital-marketing'),
        'section'  => 'seo_digital_marketing_pro',
        'settings' => 'seo_digital_marketing_pro',
        'priority' => 1,
    )));

		$wp_customize->add_setting( 'seo_digital_marketing_logo_title', array(
			'default'           => true,
			'transport'         => 'refresh',
			'sanitize_callback' => 'seo_digital_marketing_sanitize_checkbox',
		) );
		$wp_customize->add_control( new SEO_Digital_Marketing_Toggle_Control( $wp_customize, 'seo_digital_marketing_logo_title', array(
			'label'       => esc_html__( 'Show Site Title', 'seo-digital-marketing' ),
			'section'     => 'title_tagline',
			'type'        => 'toggle',
			'settings'    => 'seo_digital_marketing_logo_title',
		) ) );

    $wp_customize->add_setting( 'seo_digital_marketing_logo_tagline_text', array(
			'default'           => false,
			'transport'         => 'refresh',
			'sanitize_callback' => 'seo_digital_marketing_sanitize_checkbox',
		) );
	$wp_customize->add_control( new SEO_Digital_Marketing_Toggle_Control( $wp_customize, 'seo_digital_marketing_logo_tagline_text', array(
		'label'       => esc_html__( 'Show Site Tagline', 'seo-digital-marketing' ),
		'section'     => 'title_tagline',
		'type'        => 'toggle',
		'settings'    => 'seo_digital_marketing_logo_tagline_text',
	) ) );

    // Theme General Settings
    $wp_customize->add_section('seo_digital_marketing_theme_settings',array(
        'title' => __('Theme General Settings', 'seo-digital-marketing'),
        'priority' => 1
    ) );

    $wp_customize->add_setting( 'seo_digital_marketing_sticky_header', array(
		'default'           => false,
		'transport'         => 'refresh',
		'sanitize_callback' => 'seo_digital_marketing_sanitize_checkbox',
	) );
	$wp_customize->add_control( new SEO_Digital_Marketing_Toggle_Control( $wp_customize, 'seo_digital_marketing_sticky_header', array(
		'label'       => esc_html__( 'Show Sticky Header', 'seo-digital-marketing' ),
		'section'     => 'seo_digital_marketing_theme_settings',
		'type'        => 'toggle',
		'settings'    => 'seo_digital_marketing_sticky_header',
	) ) );

    //theme width

	$wp_customize->add_section('seo_digital_marketing_theme_width_settings',array(
        'title' => __('Theme Width Option', 'seo-digital-marketing'),
    ) );

	$wp_customize->add_setting('seo_digital_marketing_width_options',array(
        'default' => 'full_width',
        'sanitize_callback' => 'seo_digital_marketing_sanitize_choices'
	));
	$wp_customize->add_control('seo_digital_marketing_width_options',array(
        'type' => 'select',
        'label' => __('Theme Width Option','seo-digital-marketing'),
        'section' => 'seo_digital_marketing_theme_width_settings',
        'choices' => array(
            'full_width' => __('Fullwidth','seo-digital-marketing'),
            'Container' => __('Container','seo-digital-marketing'),
            'container_fluid' => __('Container Fluid','seo-digital-marketing'),
        ),
	) );

	// Post Layouts
    $wp_customize->add_section('seo_digital_marketing_layout',array(
        'title' => __('Post Layout', 'seo-digital-marketing'),
        'description' => __( 'Change the post layout from below options', 'seo-digital-marketing' ),
        'priority' => 1
    ) );

	$wp_customize->add_setting( 'seo_digital_marketing_post_sidebar', array(
		'default'           => false,
		'transport'         => 'refresh',
		'sanitize_callback' => 'seo_digital_marketing_sanitize_checkbox',
	) );
	$wp_customize->add_control( new SEO_Digital_Marketing_Toggle_Control( $wp_customize, 'seo_digital_marketing_post_sidebar', array(
		'label'       => esc_html__( 'Show Fullwidth', 'seo-digital-marketing' ),
		'section'     => 'seo_digital_marketing_layout',
		'type'        => 'toggle',
		'settings'    => 'seo_digital_marketing_post_sidebar',
	) ) );

	$wp_customize->add_setting( 'seo_digital_marketing_single_post_sidebar', array(
		'default'           => false,
		'transport'         => 'refresh',
		'sanitize_callback' => 'seo_digital_marketing_sanitize_checkbox',
	) );
	$wp_customize->add_control( new SEO_Digital_Marketing_Toggle_Control( $wp_customize, 'seo_digital_marketing_single_post_sidebar', array(
		'label'       => esc_html__( 'Show Single Post Fullwidth', 'seo-digital-marketing' ),
		'section'     => 'seo_digital_marketing_layout',
		'type'        => 'toggle',
		'settings'    => 'seo_digital_marketing_single_post_sidebar',
	) ) );

    $wp_customize->add_setting('seo_digital_marketing_post_option',array(
		'default' => 'simple_post',
		'sanitize_callback' => 'seo_digital_marketing_sanitize_select'
	));
	$wp_customize->add_control('seo_digital_marketing_post_option',array(
		'label' => esc_html__('Select Layout','seo-digital-marketing'),
		'section' => 'seo_digital_marketing_layout',
		'setting' => 'seo_digital_marketing_post_option',
		'type' => 'radio',
        'choices' => array(
            'simple_post' => __('Simple Post','seo-digital-marketing'),
            'grid_post' => __('Grid Post','seo-digital-marketing'),
        ),
	));

    $wp_customize->add_setting('seo_digital_marketing_grid_column',array(
		'default' => '3_column',
		'sanitize_callback' => 'seo_digital_marketing_sanitize_select'
	));
	$wp_customize->add_control('seo_digital_marketing_grid_column',array(
		'label' => esc_html__('Grid Post Per Row','seo-digital-marketing'),
		'section' => 'seo_digital_marketing_layout',
		'setting' => 'seo_digital_marketing_grid_column',
		'type' => 'radio',
        'choices' => array(
            '1_column' => __('1','seo-digital-marketing'),
            '2_column' => __('2','seo-digital-marketing'),
            '3_column' => __('3','seo-digital-marketing'),
            '4_column' => __('4','seo-digital-marketing'),
            '5_column' => __('6','seo-digital-marketing'),
        ),
	));

	$wp_customize->add_setting( 'seo_digital_marketing_date', array(
		'default'           => true,
		'transport'         => 'refresh',
		'sanitize_callback' => 'seo_digital_marketing_sanitize_checkbox',
	) );
	$wp_customize->add_control( new SEO_Digital_Marketing_Toggle_Control( $wp_customize, 'seo_digital_marketing_date', array(
		'label'       => esc_html__( 'Hide Date', 'seo-digital-marketing' ),
		'section'     => 'seo_digital_marketing_layout',
		'type'        => 'toggle',
		'settings'    => 'seo_digital_marketing_date',
	) ) );

	$wp_customize->add_setting( 'seo_digital_marketing_admin', array(
		'default'           => true,
		'transport'         => 'refresh',
		'sanitize_callback' => 'seo_digital_marketing_sanitize_checkbox',
	) );
	$wp_customize->add_control( new SEO_Digital_Marketing_Toggle_Control( $wp_customize, 'seo_digital_marketing_admin', array(
		'label'       => esc_html__( 'Hide Author/Admin', 'seo-digital-marketing' ),
		'section'     => 'seo_digital_marketing_layout',
		'type'        => 'toggle',
		'settings'    => 'seo_digital_marketing_admin',
	) ) );

	$wp_customize->add_setting( 'seo_digital_marketing_comment', array(
		'default'           => true,
		'transport'         => 'refresh',
		'sanitize_callback' => 'seo_digital_marketing_sanitize_checkbox',
	) );
	$wp_customize->add_control( new SEO_Digital_Marketing_Toggle_Control( $wp_customize, 'seo_digital_marketing_comment', array(
		'label'       => esc_html__( 'Hide Comment', 'seo-digital-marketing' ),
		'section'     => 'seo_digital_marketing_layout',
		'type'        => 'toggle',
		'settings'    => 'seo_digital_marketing_comment',
	) ) );

	// Top Header
    $wp_customize->add_section('seo_digital_marketing_top',array(
        'title' => __('Contact info', 'seo-digital-marketing'),
        'priority' => 1
    ) );

    $wp_customize->add_setting('seo_digital_marketing_call_number',array(
		'default' => '',
		'sanitize_callback' => 'seo_digital_marketing_sanitize_phone_number'
	));
	$wp_customize->add_control('seo_digital_marketing_call_number',array(
		'label' => esc_html__('Add Phone Number','seo-digital-marketing'),
		'section' => 'seo_digital_marketing_top',
		'setting' => 'seo_digital_marketing_call_number',
		'type'    => 'text'
	));

    $wp_customize->add_setting('seo_digital_marketing_email_address',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_email'
	));
	$wp_customize->add_control('seo_digital_marketing_email_address',array(
		'label' => esc_html__('Add Email Address','seo-digital-marketing'),
		'section' => 'seo_digital_marketing_top',
		'setting' => 'seo_digital_marketing_email_address',
		'type'    => 'text'
	));

    $wp_customize->add_setting('seo_digital_marketing_talk_btn_text',array(
		'default' => '',
		'sanitize_callback' => 'sanitize_text_field'
	));
	$wp_customize->add_control('seo_digital_marketing_talk_btn_text',array(
		'label' => esc_html__('Add Button Text','seo-digital-marketing'),
		'section' => 'seo_digital_marketing_top',
		'setting' => 'seo_digital_marketing_talk_btn_text',
		'type'    => 'text'
	));

    $wp_customize->add_setting('seo_digital_marketing_talk_btn_link',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control('seo_digital_marketing_talk_btn_link',array(
		'label' => esc_html__('Add Button URL','seo-digital-marketing'),
		'section' => 'seo_digital_marketing_top',
		'setting' => 'seo_digital_marketing_talk_btn_link',
		'type'    => 'url'
	));

	// Social Media
    $wp_customize->add_section('seo_digital_marketing_urls',array(
        'title' => __('Social Media', 'seo-digital-marketing'),
        'description' => __( 'Add social media links in the below feilds', 'seo-digital-marketing' ),
        'priority' => 3
    ) );

	$wp_customize->add_setting('seo_digital_marketing_facebook',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control('seo_digital_marketing_facebook',array(
		'label' => esc_html__('Facebook URL','seo-digital-marketing'),
		'section' => 'seo_digital_marketing_urls',
		'setting' => 'seo_digital_marketing_facebook',
		'type'    => 'url'
	));

	$wp_customize->add_setting('seo_digital_marketing_twitter',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control('seo_digital_marketing_twitter',array(
		'label' => esc_html__('Twitter URL','seo-digital-marketing'),
		'section' => 'seo_digital_marketing_urls',
		'setting' => 'seo_digital_marketing_twitter',
		'type'    => 'url'
	));

	$wp_customize->add_setting('seo_digital_marketing_youtube',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control('seo_digital_marketing_youtube',array(
		'label' => esc_html__('Youtube URL','seo-digital-marketing'),
		'section' => 'seo_digital_marketing_urls',
		'setting' => 'seo_digital_marketing_youtube',
		'type'    => 'url'
	));

	$wp_customize->add_setting('seo_digital_marketing_instagram',array(
		'default' => '',
		'sanitize_callback' => 'esc_url_raw'
	));
	$wp_customize->add_control('seo_digital_marketing_instagram',array(
		'label' => esc_html__('Instagram URL','seo-digital-marketing'),
		'section' => 'seo_digital_marketing_urls',
		'setting' => 'seo_digital_marketing_instagram',
		'type'    => 'url'
	));

    //Slider
	$wp_customize->add_section( 'seo_digital_marketing_slider_section' , array(
    	'title'      => __( 'Slider Settings', 'seo-digital-marketing' ),
    	'description' => __('Slider Image Dimension ( 600px x 700px )','seo-digital-marketing'),
		'priority'   => 3,
	) );

	$wp_customize->add_setting( 'seo_digital_marketing_slider_arrows', array(
		'default'           => false,
		'transport'         => 'refresh',
		'sanitize_callback' => 'seo_digital_marketing_sanitize_checkbox',
	) );
	$wp_customize->add_control( new SEO_Digital_Marketing_Toggle_Control( $wp_customize, 'seo_digital_marketing_slider_arrows', array(
		'label'       => esc_html__( 'Check to show slider', 'seo-digital-marketing' ),
		'section'     => 'seo_digital_marketing_slider_section',
		'type'        => 'toggle',
		'settings'    => 'seo_digital_marketing_slider_arrows',
	) ) );

	$args = array('numberposts' => -1);
	$post_list = get_posts($args);
	$i = 0;
	$pst_sls[]= __('Select','seo-digital-marketing');
	foreach ($post_list as $key => $p_post) {
		$pst_sls[$p_post->ID]=$p_post->post_title;
	}
	for ( $i = 1; $i <= 4; $i++ ) {
		$wp_customize->add_setting('seo_digital_marketing_post_setting'.$i,array(
			'sanitize_callback' => 'seo_digital_marketing_sanitize_select',
		));
		$wp_customize->add_control('seo_digital_marketing_post_setting'.$i,array(
			'type'    => 'select',
			'choices' => $pst_sls,
			'label' => __('Select post','seo-digital-marketing'),
			'section' => 'seo_digital_marketing_slider_section',
		));
	}
	wp_reset_postdata();

	// Skills Section
	$wp_customize->add_section( 'seo_digital_marketing_skill_section' , array(
    	'title'      => __( 'Skills Section Settings', 'seo-digital-marketing' ),
		'priority'   => 4,
	) );

	$wp_customize->add_setting('seo_digital_marketing_skill_title',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('seo_digital_marketing_skill_title',array(
		'label'	=> esc_html__('Section Title ','seo-digital-marketing'),
		'section'	=> 'seo_digital_marketing_skill_section',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('seo_digital_marketing_skill_btn_text',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('seo_digital_marketing_skill_btn_text',array(
		'label'	=> esc_html__('Section Text','seo-digital-marketing'),
		'section'	=> 'seo_digital_marketing_skill_section',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('seo_digital_marketing_skill_increament',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('seo_digital_marketing_skill_increament',array(
		'label'	=> esc_html__('skill Box Increament','seo-digital-marketing'),
		'section'	=> 'seo_digital_marketing_skill_section',
		'type'		=> 'number',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 0,
			'max'              => 8,
		),
	));

	$skill = get_theme_mod('seo_digital_marketing_skill_increament');

	for ($i=1; $i <= $skill ; $i++) {

		$wp_customize->add_setting('seo_digital_marketing_skill_box_icon'.$i,array(
			'default'	=> '',
			'sanitize_callback'	=> 'sanitize_text_field'
		));
		$wp_customize->add_control('seo_digital_marketing_skill_box_icon'.$i,array(
			'label'	=> esc_html__('Icon ','seo-digital-marketing').$i,
			'description' => esc_html__('Add the fontawesome icon ex: fas fa-server','seo-digital-marketing'),
			'section'	=> 'seo_digital_marketing_skill_section',
			'type'		=> 'text'
		));

		$wp_customize->add_setting('seo_digital_marketing_skill_box_number'.$i,array(
			'default'	=> '',
			'sanitize_callback'	=> 'sanitize_text_field'
		));
		$wp_customize->add_control('seo_digital_marketing_skill_box_number'.$i,array(
			'label'	=> esc_html__('Title ','seo-digital-marketing').$i,
			'section'	=> 'seo_digital_marketing_skill_section',
			'type'		=> 'text'
		));

		$wp_customize->add_setting('seo_digital_marketing_skill_box_title'.$i,array(
			'default'	=> '',
			'sanitize_callback'	=> 'sanitize_text_field'
		));
		$wp_customize->add_control('seo_digital_marketing_skill_box_title'.$i,array(
			'label'	=> esc_html__('Text ','seo-digital-marketing').$i,
			'section'	=> 'seo_digital_marketing_skill_section',
			'type'		=> 'text'
		));

	    $wp_customize->add_setting( 'seo_digital_marketing_skill_box_image'.$i, array(
	        'default' => '',
	        'sanitize_callback' => 'esc_url_raw'
	    ));
	    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'seo_digital_marketing_skill_box_image'.$i, array(
	        'label' => esc_html__('Upload Image ','seo-digital-marketing').$i,
	        'section' => 'seo_digital_marketing_skill_section',
	        'settings' => 'seo_digital_marketing_skill_box_image'.$i,
	    )));
	}

	//Footer
    $wp_customize->add_section( 'seo_digital_marketing_footer_copyright', array(
    	'title'      => esc_html__( 'Footer Text', 'seo-digital-marketing' ),
    	'priority' => 6
	) );

    $wp_customize->add_setting('seo_digital_marketing_footer_text',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('seo_digital_marketing_footer_text',array(
		'label'	=> esc_html__('Copyright Text','seo-digital-marketing'),
		'section'	=> 'seo_digital_marketing_footer_copyright',
		'type'		=> 'text'
	));

	$wp_customize->get_setting( 'blogname' )->transport          = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport   = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
		'selector' => '.site-title a',
		'render_callback' => 'seo_digital_marketing_customize_partial_blogname',
	) );
	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
		'selector' => '.site-description',
		'render_callback' => 'seo_digital_marketing_customize_partial_blogdescription',
	) );

	//front page
	$num_sections = apply_filters( 'seo_digital_marketing_front_page_sections', 4 );

	// Create a setting and control for each of the sections available in the theme.
	for ( $i = 1; $i < ( 1 + $num_sections ); $i++ ) {
		$wp_customize->add_setting( 'panel_' . $i, array(
			'default'           => false,
			'sanitize_callback' => 'seo_digital_marketing_sanitize_dropdown_pages',
			'transport'         => 'postMessage',
		) );

		$wp_customize->add_control( 'panel_' . $i, array(
			/* translators: %d is the front page section number */
			'label'          => sprintf( __( 'Front Page Section %d Content', 'seo-digital-marketing' ), $i ),
			'description'    => ( 1 !== $i ? '' : __( 'Select pages to feature in each area from the dropdowns. Add an image to a section by setting a featured image in the page editor. Empty sections will not be displayed.', 'seo-digital-marketing' ) ),
			'section'        => 'theme_options',
			'type'           => 'dropdown-pages',
			'allow_addition' => true,
			'active_callback' => 'seo_digital_marketing_is_static_front_page',
		) );

		$wp_customize->selective_refresh->add_partial( 'panel_' . $i, array(
			'selector'            => '#panel' . $i,
			'render_callback'     => 'seo_digital_marketing_front_page_section',
			'container_inclusive' => true,
		) );
	}
}
add_action( 'customize_register', 'seo_digital_marketing_customize_register' );

function seo_digital_marketing_customize_partial_blogname() {
	bloginfo( 'name' );
}
function seo_digital_marketing_customize_partial_blogdescription() {
	bloginfo( 'description' );
}
function seo_digital_marketing_is_static_front_page() {
	return ( is_front_page() && ! is_home() );
}
function seo_digital_marketing_is_view_with_layout_option() {
	return ( is_page() || ( is_archive() && ! is_active_sidebar( 'sidebar-1' ) ) );
}

define('SEO_DIGITAL_MARKETING_PRO_LINK',__('https://www.ovationthemes.com/wordpress/digital-marketing-wordpress-theme/','seo-digital-marketing'));

/* Pro control */
if (class_exists('WP_Customize_Control') && !class_exists('SEO_Digital_Marketing_Pro_Control')):
    class SEO_Digital_Marketing_Pro_Control extends WP_Customize_Control{

    public function render_content(){?>
        <label style="overflow: hidden; zoom: 1;">
	        <div class="col-md upsell-btn">
                <a href="<?php echo esc_url( SEO_DIGITAL_MARKETING_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE SEO MARKETING PREMIUM','seo-digital-marketing');?> </a>
	        </div>
            <div class="col-md">
                <img class="seo_digital_marketing_img_responsive " src="<?php echo esc_url(get_template_directory_uri()); ?>/screenshot.png">
            </div>
	        <div class="col-md">
	            <h3 style="margin-top:10px; margin-left: 20px; text-decoration:underline; color:#333;"><?php esc_html_e('SEO MARKETING PREMIUM - Features', 'seo-digital-marketing'); ?></h3>
                <ul style="padding-top:10px">
                    <li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Responsive Design', 'seo-digital-marketing');?> </li>
                    <li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Boxed or fullwidth layout', 'seo-digital-marketing');?> </li>
                    <li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Shortcode Support', 'seo-digital-marketing');?> </li>
                    <li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Demo Importer', 'seo-digital-marketing');?> </li>
                    <li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Section Reordering', 'seo-digital-marketing');?> </li>
                    <li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Contact Page Template', 'seo-digital-marketing');?> </li>
                    <li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Multiple Blog Layouts', 'seo-digital-marketing');?> </li>
                    <li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Unlimited Color Options', 'seo-digital-marketing');?> </li>
                    <li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Designed with HTML5 and CSS3', 'seo-digital-marketing');?> </li>
                    <li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Customizable Design & Code', 'seo-digital-marketing');?> </li>
                    <li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Cross Browser Support', 'seo-digital-marketing');?> </li>
                    <li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Detailed Documentation Included', 'seo-digital-marketing');?> </li>
                    <li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Stylish Custom Widgets', 'seo-digital-marketing');?> </li>
                    <li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Patterns Background', 'seo-digital-marketing');?> </li>
                    <li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('WPML Compatible (Translation Ready)', 'seo-digital-marketing');?> </li>
                    <li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Woo-commerce Compatible', 'seo-digital-marketing');?> </li>
                    <li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Full Support', 'seo-digital-marketing');?> </li>
                    <li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('10+ Sections', 'seo-digital-marketing');?> </li>
                    <li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Live Customizer', 'seo-digital-marketing');?> </li>
                   	<li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('AMP Ready', 'seo-digital-marketing');?> </li>
                   	<li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Clean Code', 'seo-digital-marketing');?> </li>
                   	<li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('SEO Friendly', 'seo-digital-marketing');?> </li>
                   	<li class="upsell-seo_digital_marketing"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Supper Fast', 'seo-digital-marketing');?> </li>
                </ul>
        	</div>
		    <div class="col-md upsell-btn upsell-btn-bottom">
	            <a href="<?php echo esc_url( SEO_DIGITAL_MARKETING_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE SEO MARKETING PREMIUM','seo-digital-marketing');?> </a>
		    </div>
        </label>
    <?php } }
endif;
